@@ -35,7 +35,7 @@ c     t_i = S_i*sqrt(n/(i*(n-i)))/sqrt((tss - S_i^2*n/(i*(n-i)))/(n-2))
       sumxi = x(1)
       ostat = 0.0
       eloc = -1
-      dn = dfloat(n)
+      dn = dble(n)
       di = 1.0
       do 20 i = 2,n-2
          di = di + 1.0
